@@ -1,5 +1,6 @@
 use crate::*;
 
+/// Allows rui to iterate over a tuple of `Views`.
 pub trait ViewTuple {
     fn foreach_view<F: FnMut(&dyn View)>(&self, f: &mut F);
     fn len(&self) -> usize;
@@ -11,7 +12,7 @@ pub enum StackOrientation {
     Z,
 }
 
-pub struct Stack<VT: ViewTuple> {
+struct Stack<VT: ViewTuple> {
     orientation: StackOrientation,
     children: VT,
 }
@@ -49,19 +50,30 @@ impl<VT: ViewTuple> View for Stack<VT> {
         let mut c = 0;
         self.children.foreach_view(&mut |child| {
             let child_id = id.child(&c);
-            let offset = cx
+            let layout_box = cx
                 .layout
                 .entry(child_id)
                 .or_insert(LayoutBox::default())
-                .offset;
+                .clone();
 
             vger.save();
 
-            vger.translate(offset);
+            vger.translate(layout_box.offset);
 
             (*child).draw(child_id, cx, vger);
             c += 1;
 
+            if DEBUG_LAYOUT {
+                let paint = vger.color_paint(CONTROL_BACKGROUND);
+                vger.stroke_rect(
+                    layout_box.rect.min(),
+                    layout_box.rect.max(),
+                    0.0,
+                    1.0,
+                    paint,
+                );
+            }
+
             vger.restore();
         })
     }
@@ -74,39 +86,37 @@ impl<VT: ViewTuple> View for Stack<VT> {
                 let proposed_child_size = LocalSize::new(sz.width / n, sz.height);
 
                 let mut c = 0;
-                let mut width_sum = 0.0;
+                let mut x = 0.0;
                 self.children.foreach_view(&mut |child| {
                     let child_id = id.child(&c);
+                    let child_rect = LocalRect::new([x, 0.0].into(), proposed_child_size);
                     let child_size = child.layout(child_id, proposed_child_size, cx, vger);
 
-                    cx.layout.entry(child_id).or_default().offset =
-                        [width_sum, (sz.height - child_size.height) / 2.0].into();
+                    cx.layout.entry(child_id).or_default().offset = align_h(LocalRect::new(LocalPoint::origin(), child_size), child_rect, HAlignment::Center);
 
-                    width_sum += child_size.width;
+                    x += proposed_child_size.width;
                     c += 1;
                 });
 
-                LocalSize::new(width_sum, sz.height)
+                sz
             }
             StackOrientation::Vertical => {
                 let proposed_child_size = LocalSize::new(sz.width, sz.height / n);
 
                 let mut c = 0;
                 let mut y = sz.height;
-                let mut height_sum = 0.0;
                 self.children.foreach_view(&mut |child| {
                     let child_id = id.child(&c);
+                    let child_rect = LocalRect::new([0.0, y - proposed_child_size.height].into(), proposed_child_size);
                     let child_size = child.layout(child_id, proposed_child_size, cx, vger);
 
-                    y -= child_size.height;
-                    cx.layout.entry(child_id).or_default().offset =
-                        [(sz.width - child_size.width) / 2.0, y].into();
+                    y -= proposed_child_size.height;
+                    cx.layout.entry(child_id).or_default().offset = align_v(LocalRect::new(LocalPoint::origin(), child_size), child_rect, VAlignment::Middle);
 
-                    height_sum += child_size.height;
                     c += 1;
                 });
 
-                LocalSize::new(sz.width, height_sum)
+                sz
             }
             StackOrientation::Z => {
                 let mut c = 0;
@@ -268,16 +278,16 @@ impl<A: View, B: View, C: View, D: View, E: View, F: View, G: View, H: View> Vie
 }
 
 /// Horizontal stack of up to 8 Views in a tuple. Each item can be a different view type.
-pub fn hstack<VT: ViewTuple>(children: VT) -> Stack<VT> {
+pub fn hstack<VT: ViewTuple>(children: VT) -> impl View {
     Stack::new(StackOrientation::Horizontal, children)
 }
 
 /// Vertical stack of up to 8 Views in a tuple. Each item can be a different view type.
-pub fn vstack<VT: ViewTuple>(children: VT) -> Stack<VT> {
+pub fn vstack<VT: ViewTuple>(children: VT) -> impl View {
     Stack::new(StackOrientation::Vertical, children)
 }
 
 /// Stack of up to 8 overlaid Views in a tuple. Each item can be a different view type.
-pub fn zstack<VT: ViewTuple>(children: VT) -> Stack<VT> {
+pub fn zstack<VT: ViewTuple>(children: VT) -> impl View {
     Stack::new(StackOrientation::Z, children)
 }
