@@ -1,5 +1,6 @@
 use crate::*;
 
+/// Struct for `text`.
 pub struct Text {
     text: String,
     size: u32,
@@ -15,9 +16,7 @@ impl View for Text {
     }
     fn process(&self, _event: &Event, _id: ViewID, _cx: &mut Context, _vger: &mut VGER) {}
     fn draw(&self, _id: ViewID, _cx: &mut Context, vger: &mut VGER) {
-        let origin = vger
-            .text_bounds(self.text.as_str(), self.size, None)
-            .origin;
+        let origin = vger.text_bounds(self.text.as_str(), self.size, None).origin;
 
         vger.save();
         vger.translate([-origin.x, -origin.y]);
@@ -25,9 +24,7 @@ impl View for Text {
         vger.restore();
     }
     fn layout(&self, id: ViewID, _sz: LocalSize, cx: &mut Context, vger: &mut VGER) -> LocalSize {
-        let size = vger
-            .text_bounds(self.text.as_str(), self.size, None)
-            .size;
+        let size = vger.text_bounds(self.text.as_str(), self.size, None).size;
 
         cx.layout.insert(
             id,
@@ -53,7 +50,10 @@ impl View for Text {
 
 impl Text {
     pub fn font_size(self, size: u32) -> Self {
-        Self { text: self.text, size }
+        Self {
+            text: self.text,
+            size,
+        }
     }
 }
 
